@@ -1,4 +1,4 @@
-import matplotlib.pyplot as plt
+﻿import matplotlib.pyplot as plt
 import numpy as np
 
 def plotComponents1D(X, y, labels, use_markers=False, ax=None, legends = None):
